
[![pipeline status](https://gitlab.gwdg.de/mpi-dortmund/sphire/cryolo/badges/master/pipeline.svg)](https://gitlab.gwdg.de/mpi-dortmund/sphire/cryolo/-/commits/predict3d) 
[![coverage report](https://gitlab.gwdg.de/mpi-dortmund/sphire/cryolo/badges/master/coverage.svg)](https://gitlab.gwdg.de/mpi-dortmund/sphire/cryolo/-/commits/predict3d) 

# SPHIRE-crYOLO

Deep learning particle picking procedure based on YOLOv2.
Please see [our website](https://cryolo.readthedocs.io/en/stable/) for more information.

## License
The license information can be found here:

[EULA license of crYOLO](https://cryolo.readthedocs.io/en/stable/other/license.html)

## Paper
If you use crYOLO, please cite

Wagner, T. et al. SPHIRE-crYOLO is a fast and accurate fully automated particle picker for cryo-EM. Communications Biology 2, (2019).
 
 https://doi.org/10.1038/s42003-019-0437-z